@@ -113,10 +113,18 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 				_, _ = fmt.Fprint(writer, tagColor(">"))
 				startTagClosed = true
 			}
-			if !hasContent && level > 0 {
-				_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+
+			for index, commentLine := range strings.Split(string(typedToken), "\n") {
+				if !hasContent && level > 0 {
+					_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+				}
+				if index == 0 {
+					_, _ = fmt.Fprint(writer, commentColor("<!--"))
+				}
+				_, _ = fmt.Fprint(writer, commentColor(commentLine))
 			}
-			_, _ = fmt.Fprint(writer, commentColor("<!--"+string(typedToken)+"-->"))
+			_, _ = fmt.Fprint(writer, commentColor("-->"))
+
 			if level == 0 {
 				_, _ = fmt.Fprint(writer, "\n")
 			}
@@ -271,11 +279,13 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 			docType := tokenizer.Text()
 			_, _ = fmt.Fprintf(writer, "%s%s%s\n", tagColor("<!doctype "), string(docType), tagColor(">"))
 		case html.CommentToken:
-			comment := tokenizer.Raw()
-			if !hasContent && level > 0 {
-				_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+			for _, commentLine := range strings.Split(string(tokenizer.Raw()), "\n") {
+				if !hasContent && level > 0 {
+					_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+				}
+				_, _ = fmt.Fprint(writer, commentColor(commentLine))
 			}
-			_, _ = fmt.Fprint(writer, commentColor(string(comment)))
+
 			if level == 0 {
 				_, _ = fmt.Fprint(writer, "\n")
 			}
@@ -287,17 +297,30 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 	return nil
 }
 
-func PagerPrint(reader io.Reader) error {
+func IsHTML(input string) bool {
+	input = strings.ToLower(input)
+	htmlMarkers := []string{"html", "<!d", "<body"}
+
+	for _, htmlMarker := range htmlMarkers {
+		if strings.Contains(input, htmlMarker) {
+			return true
+		}
+	}
+
+	return false
+}
+
+func PagerPrint(reader io.Reader, writer io.Writer) error {
 	pager := os.Getenv("PAGER")
 
 	if pager != "less" {
-		_, err := io.Copy(os.Stdout, reader)
+		_, err := io.Copy(writer, reader)
 		return err
 	}
 
 	cmd := exec.Command(pager, "--quit-if-one-screen", "--no-init", "--RAW-CONTROL-CHARS")
 	cmd.Stdin = reader
-	cmd.Stdout = os.Stdout
+	cmd.Stdout = writer
 
 	return cmd.Run()
 }
