@@ -1,6 +1,7 @@
 package utils
 
 import (
+	"bytes"
 	"github.com/stretchr/testify/assert"
 	"io"
 	"os"
@@ -9,6 +10,16 @@ import (
 	"testing"
 )
 
+func getFileReader(filename string) io.Reader {
+	reader, err := os.Open(filename)
+
+	if err != nil {
+		panic(err)
+	}
+
+	return reader
+}
+
 func TestFormatXml(t *testing.T) {
 	files := map[string]string{
 		"unformatted.xml":  "formatted.xml",
@@ -17,6 +28,7 @@ func TestFormatXml(t *testing.T) {
 		"unformatted4.xml": "formatted4.xml",
 		"unformatted5.xml": "formatted5.xml",
 		"unformatted6.xml": "formatted6.xml",
+		"unformatted7.xml": "formatted7.xml",
 	}
 
 	for unformattedFile, expectedFile := range files {
@@ -38,6 +50,7 @@ func TestFormatHtml(t *testing.T) {
 		"unformatted.html":  "formatted.html",
 		"unformatted2.html": "formatted2.html",
 		"unformatted3.html": "formatted3.html",
+		"unformatted4.html": "formatted4.html",
 		"unformatted.xml":   "formatted.xml",
 	}
 
@@ -55,12 +68,35 @@ func TestFormatHtml(t *testing.T) {
 	}
 }
 
-func getFileReader(filename string) io.Reader {
-	reader, err := os.Open(filename)
+func TestXPathQuery(t *testing.T) {
+	fileReader := getFileReader(path.Join("..", "..", "test", "data", "xml", "formatted.xml"))
+	output := new(strings.Builder)
+	err := XPathQuery(fileReader, output, "//first_name", true)
+	assert.Nil(t, err)
+	assert.Equal(t, "John", strings.Trim(output.String(), "\n"))
+}
 
-	if err != nil {
-		panic(err)
-	}
+func TestCSSQuery(t *testing.T) {
+	fileReader := getFileReader(path.Join("..", "..", "test", "data", "html", "formatted.html"))
+	output := new(strings.Builder)
+	err := CSSQuery(fileReader, output, "body > p")
+	assert.Nil(t, err)
+	assert.Equal(t, "text", strings.Trim(output.String(), "\n"))
+}
 
-	return reader
+func TestIsHTML(t *testing.T) {
+	assert.True(t, IsHTML("<html>"))
+	assert.True(t, IsHTML("<!doctype>"))
+	assert.True(t, IsHTML("<body> ..."))
+
+	assert.False(t, IsHTML("<?xml ?>"))
+	assert.False(t, IsHTML("<root></root>"))
+}
+
+func TestPagerPrint(t *testing.T) {
+	var output bytes.Buffer
+	fileReader := getFileReader(path.Join("..", "..", "test", "data", "html", "formatted.html"))
+	err := PagerPrint(fileReader, &output)
+	assert.Nil(t, err)
+	assert.Contains(t, output.String(), "<html>")
 }
